@@ -157,7 +157,7 @@ void Board::resizeBoard(int w, int h)
 	boardHandler->gotoFirstMove();
 
     // Clear background before canvas is resized
-    canvas->setBackgroundPixmap(*(ImageHandler::getTablePixmap()));
+    canvas->setBackgroundPixmap(*(ImageHandler::getTablePixmap(setting->readEntry("SKIN_TABLE"))));
 
     // Resize canvas
     canvas->resize(w, h);
@@ -254,10 +254,11 @@ void Board::drawBackground()
     //QBrush table;
     // table.setPixmap(*(imageHandler->getTablePixmap()));
     //table.setPixmap(*(ImageHandler::getTablePixmap()));
+    //painter.flush();
     painter.begin(&all);
     painter.setPen(NoPen);
     //painter.fillRect(0, 0, w, h, table);
-    painter.drawTiledPixmap (0, 0, w, h,*(ImageHandler::getTablePixmap()));
+    painter.drawTiledPixmap (0, 0, w, h,*(ImageHandler::getTablePixmap(setting->readEntry("SKIN_TABLE"))));
     //painter.fillRect(
     painter.drawTiledPixmap (
 		offsetX - offset,
@@ -265,69 +266,7 @@ void Board::drawBackground()
 		board_pixel_size + offset*2,
 		board_pixel_size + offset*2,
 		*(ImageHandler::getBoardPixmap(setting->readEntry("SKIN"))));
-//		board);
 
-   
-/*    
-// code for providing shadow / light effetcs on the goban border.
-// not very satisfactory because the raster op is not what we need here.
-
-    QColor c = QColor("darkGrey") ;   
-      
-    painter.setRasterOp(Qt::AndROP);
-
-    painter.setPen(c.dark(145));
-    painter.drawLine( offsetX - offset,
-		      offsetY - offset,
-                      offsetX - offset,
-                      offsetY + board_pixel_size + offset);
-                      
-     painter.setPen(c);
-     painter.drawLine(offsetX - offset +1,
-		      offsetY - offset,
-                      offsetX - offset +1,
-                      offsetY + board_pixel_size + offset);                     
-
-
-     painter.setPen(c.dark(145));
-     painter.drawLine( offsetX - offset,
-		      offsetY + board_pixel_size + offset -1 ,
-                      offsetX + board_pixel_size + offset,
-                      offsetY + board_pixel_size + offset -1);
-
-     painter.setPen(c);
-     painter.drawLine( offsetX - offset,
-		      offsetY + board_pixel_size + offset -2,
-                      offsetX + board_pixel_size + offset,
-                      offsetY + board_pixel_size + offset -2 ); 
-
-    painter.setRasterOp(Qt::OrROP);
-
-    painter.setPen(c.light(30));
-    painter.drawLine( offsetX + board_pixel_size + offset-1,
-		                  offsetY - offset,
-                      offsetX + board_pixel_size + offset-1,
-                      offsetY + board_pixel_size + offset -1);
-
-     painter.setPen(c);
-     painter.drawLine(offsetX + board_pixel_size + offset-2,
-		                  offsetY - offset,
-                      offsetX + board_pixel_size + offset-2,
-                      offsetY + board_pixel_size + offset -1);
-
-
-     painter.setPen(c.light(30));
-     painter.drawLine(offsetX - offset,
-		      offsetY  - offset,
-                      offsetX + board_pixel_size + offset -1,
-                      offsetY - offset);
-
-     painter.setPen(c);
-     painter.drawLine( offsetX - offset,
-		                  offsetY  - offset +1,
-                      offsetX + board_pixel_size + offset -1,
-                      offsetY - offset +1);
-*/    
     	painter.end();
 
 	QImage image = all.convertToImage();
@@ -1172,7 +1111,7 @@ void Board::setMark(int x, int y, MarkType t, bool update, QString txt, bool ove
 				letterPool[n] = true;
 		}
 		m = new MarkText(imageHandler, x, y, square_size, txt, canvas, col, n, false, overlay);
-		setMarkText(x, y, txt);
+		//setMarkText(x, y, txt);
 		break;
 		
     case markNumber:
@@ -1277,6 +1216,7 @@ void Board::setMarkText(int x, int y, const QString &txt)
     m->setSize((double)square_size, (double)square_size);
     m->setX(offsetX + square_size * (x-1) - m->getSizeX()/2);
     m->setY(offsetY + square_size * (y-1) - m->getSizeY()/2);
+	
 }
 
 Mark* Board::hasMark(int x, int y)
