@@ -12,6 +12,8 @@
 #include "move.h"
 #include <qcanvas.h>
 #include <qdatetime.h>
+#include <qpainter.h>
+#include <qptrlist.h>
 
 class ImageHandler;
 class Mark;
@@ -173,6 +175,7 @@ private:
 	bool antiClicko;
 	QList<Mark> *marks;
 	QList<Stone> *ghosts;
+//	QPtrList<QCanvasLine> *hgatter;
 	Mark *lastMoveMark;
 	bool numberPool[400];
 	bool letterPool[52];
@@ -182,6 +185,7 @@ private:
 	QTime wheelTime;
 	ButtonState mouseState;
 	NodeResults *nodeResultsDlg;
+//	QPainter painter;
 
 #ifdef Q_WS_WIN
 	bool resizeDelayFlag;
