@@ -36,6 +36,7 @@ GameDialog::GameDialog(QWidget* parent, const char* name, bool modal, WFlags fl)
 
 GameDialog::~GameDialog()
 {
+
 }
 
 void GameDialog::slot_stats_opponent()
@@ -324,15 +325,18 @@ qDebug("#### GameDialog::slot_offer()");
 void GameDialog::slot_decline()
 {
 qDebug("#### GameDialog::slot_decline()");
+	
+	QString opponent = (playerWhiteEdit->isReadOnly() ? playerBlackEdit->text():playerWhiteEdit->text());
+
 	if (buttonOffer->isOn())
 	{
 		// match has been offered
-    // !! there seem to be not "setOn" in the code (apart init, but this should not reach this code)
+		// !! there seem to be not "setOn" in the code (apart init, but this should not reach this code)
 		emit signal_sendcommand("withdraw", false);
 		buttonOffer->setOn(false);
 		buttonOffer->setText(tr("Offer"));
 	}
-	else if (playerWhiteEdit->isReadOnly())
+/*	else if (playerWhiteEdit->isReadOnly())
 	{
 		// ok, I am white
 		emit signal_sendcommand("decline " + playerBlackEdit->text(), false);
@@ -343,12 +347,26 @@ qDebug("#### GameDialog::slot_decline()");
 		emit signal_sendcommand("decline " + playerWhiteEdit->text(), false);
 	}
 
-	buttonDecline->setDisabled(true);
-	buttonOffer->setText(tr("Offer"));
-	buttonCancel->setEnabled(true);
+	//buttonDecline->setDisabled(true);
+	//buttonOffer->setText(tr("Offer"));
+	//buttonCancel->setEnabled(true);
 
-  reject();
-  
+  	//reject();
+*/
+	emit signal_sendcommand("decline " + opponent, false);
+	emit signal_removeDialog(opponent);
+
+}
+
+void GameDialog::slot_cancel()
+{
+
+	if (is_nmatch)
+		emit signal_sendcommand("nmatch _cancel", false);
+
+	QString opponent = (playerWhiteEdit->isReadOnly() ? playerBlackEdit->text():playerWhiteEdit->text());
+
+	emit signal_removeDialog(opponent);
 }
 
 void GameDialog::slot_changed()
@@ -468,3 +486,71 @@ qDebug("#### GameDialog::slot_komirequest()");
 	else
 		buttonCancel->setEnabled(true);
 }
+
+
+void GameDialog::slot_dispute(const QString &opponent, const QString &line)
+{
+	QString val;
+
+	if (playerWhiteEdit->isReadOnly() && playerBlackEdit->text() == opponent ||
+	    playerBlackEdit->isReadOnly() && playerWhiteEdit->text() == opponent)
+
+	{
+		val = element(line,1," ");
+		if (handicapSpin->value() != val.toInt())
+		{
+			handicapSpin->setValue(val.toInt());
+			handicapSpin->setPaletteBackgroundColor(QColor::QColor("cyan"));
+		}
+		else
+			handicapSpin->unsetPalette();
+
+		val = element(line,2," ");
+		if (boardSizeSpin->value() != val.toInt())
+		{
+			boardSizeSpin->setValue(val.toInt());
+			boardSizeSpin->setPaletteBackgroundColor(QColor::QColor("cyan"));
+		}
+		else
+			boardSizeSpin->unsetPalette();
+
+		val = element(line,3," ");
+		if (timeSpin->value() != val.toInt()/60)
+		{
+			timeSpin->setValue(val.toInt()/60);
+			timeSpin->setPaletteBackgroundColor(QColor::QColor("cyan"));
+		}
+		else
+			timeSpin->unsetPalette();
+
+		val = element(line,4," ");
+		if (byoTimeSpin->value() != val.toInt()/60)
+		{
+			byoTimeSpin->setValue(val.toInt()/60);
+			byoTimeSpin->setPaletteBackgroundColor(QColor::QColor("cyan"));
+		}
+		else
+			byoTimeSpin->unsetPalette();	
+
+		//val = element(line,5," ");
+		//BY_label->setText(tr(" Byoyomi Time : (")+ val + tr(" stones)"));
+
+		val = element(line,0," ");
+		if ((playerBlackEdit->text() == opponent) && (val == "W"))
+		{
+			playerBlackEdit->setPaletteBackgroundColor(QColor::QColor("cyan"));
+			playerWhiteEdit->setPaletteBackgroundColor(QColor::QColor("cyan"));
+			slot_swapcolors();
+		}
+		else 
+		{
+			playerBlackEdit->unsetPalette();
+			playerWhiteEdit->unsetPalette();
+		}
+
+	buttonOffer->setText(tr("Accept"));
+	buttonOffer->setOn(false);
+	buttonDecline->setEnabled(true);
+	
+	}
+}
