@@ -8,9 +8,9 @@
 #include "newgame_gui.h"
 #include "gs_globals.h"
 #include "defines.h"
+#include "misc.h"
 
-
-class GameDialog : public NewGameDialog
+class GameDialog : public NewGameDialog, public Misc<QString>
 { 
 	Q_OBJECT
 
@@ -25,6 +25,7 @@ public:
 signals:
 	void signal_sendcommand(const QString &cmd, bool localecho);
 	void signal_matchsettings(const QString&, const QString&, const QString&, assessType);
+	void signal_removeDialog(const QString&);
 
 public slots:
 	// pushbuttons
@@ -34,12 +35,14 @@ public slots:
 	virtual void slot_offer(bool);
 	virtual void slot_decline();
 	virtual void slot_changed();
+	virtual void slot_cancel();
 	// parser
 	void slot_suggest(const QString&, const QString&, const QString&, const QString&, int);
 	void slot_matchcreate(const QString&, const QString&);
 	void slot_notopen(const QString&);
 	void slot_komirequest(const QString&, int, int, bool);
 	void slot_opponentopen(const QString&);
+	void slot_dispute(const QString&, const QString&);
 
 private:
 	bool have_suggestdata;
