@@ -30,7 +30,7 @@ public:
 	void init(int size);
 	void rescale(int size);//, bool smallerStones);
 	static QPixmap* getBoardPixmap(QString );//skinType s = skinLight);
-	static QPixmap* getTablePixmap() { return tablePixmap; }
+	static QPixmap* getTablePixmap(QString );//) { return tablePixmap; }
 	QCanvasPixmapArray* getStonePixmaps() const { return stonePixmaps; }
 	QCanvasPixmapArray* getGhostPixmaps() const { return ghostPixmaps; }
 	static QCanvasPixmapArray* getAlternateGhostPixmaps() { return altGhostPixmaps; }
