@@ -157,7 +157,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	connect(parser, SIGNAL(signal_addToObservationList(int)), SLOT(slot_addToObservationList(int)));
 	connect(parser, SIGNAL(signal_channelinfo(int, const QString&)), SLOT(slot_channelinfo(int, const QString&)));
 	connect(parser, SIGNAL(signal_matchrequest(const QString&, bool)), this, SLOT(slot_matchrequest(const QString&, bool)));
-  	connect(parser, SIGNAL(signal_matchCanceled(const QString&)), this, SLOT(slot_matchCanceled(const QString&)));
+  	connect(parser, SIGNAL(signal_matchCanceled(const QString&)), this, SLOT(slot_removeMatchDialog(const QString&)));
 	connect(parser, SIGNAL(signal_shout(const QString&, const QString&)), SLOT(slot_shout(const QString&, const QString&)));
 	connect(parser, SIGNAL(signal_room(const QString&, bool)),SLOT(slot_room(const QString&, bool)));
 	connect(parser, SIGNAL(signal_addSeekCondition(const QString&,const QString&, const QString&, const QString&, const QString&)),this,
@@ -165,6 +165,8 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	connect(parser, SIGNAL(signal_clearSeekCondition()),this,SLOT(slot_clearSeekCondition()));
 	connect(parser, SIGNAL(signal_cancelSeek()),this,SLOT(slot_cancelSeek()));
 	connect(parser, SIGNAL(signal_SeekList(const QString&, const QString&)),this,SLOT(slot_SeekList(const QString&, const QString&)));
+	connect(parser, SIGNAL(signal_refresh(int)),this, SLOT(slot_refresh(int)));
+
 	// connect mouse to games table/player table
 	connect(ListView_games, SIGNAL(contextMenuRequested(QListViewItem*, const QPoint&, int)),
 	                        SLOT(slot_menu_games(QListViewItem*, const QPoint&, int)));
@@ -268,7 +270,8 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 			                     setting->readEntry("HOST" + QString::number(i) + "b"),
 			                     setting->readIntEntry("HOST" + QString::number(i) + "c"),
 			                     setting->readEntry("HOST" + QString::number(i) + "d"),
-			                     setting->readEntry("HOST" + QString::number(i) + "e")));
+			                     setting->readEntry("HOST" + QString::number(i) + "e"),
+			                     setting->readEntry("HOST" + QString::number(i) + "f")));
 	}
 
 	// run slot command to initialize combobox and set host
@@ -403,6 +406,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	connect(qgoif, SIGNAL(signal_addToObservationList(int)), this, SLOT(slot_addToObservationList(int)));
 	connect(qgoif->get_qgo(), SIGNAL(signal_updateFont()), this, SLOT(slot_updateFont()));
 	connect(parser, SIGNAL(signal_timeAdded(int, bool)), qgoif, SLOT(slot_timeAdded(int, bool)));
+	//connect(parser, SIGNAL(signal_undoRequest(const QString&)), qgoif, SLOT(slot_undoRequest(const QString&)));
 
 	//gamestable
 //	connect(ListView_players, SIGNAL(contentsMoving(int, int)), this, SLOT(slot_playerContentsMoving(int, int)));
@@ -770,6 +774,7 @@ void ClientWindow::saveSettings()
 		setting->writeIntEntry("HOST" + QString::number(i) + "c", h->port());
 		setting->writeEntry("HOST" + QString::number(i) + "d", h->loginName());
 		setting->writeEntry("HOST" + QString::number(i) + "e", h->password());
+		setting->writeEntry("HOST" + QString::number(i) + "f", h->codec());
 	}
 	while (setting->readEntry("HOST" + QString::number(++i) + "a"))
 	{
@@ -779,6 +784,7 @@ void ClientWindow::saveSettings()
 		setting->writeEntry("HOST" + QString::number(i) + "c", QString());
 		setting->writeEntry("HOST" + QString::number(i) + "d", QString());
 		setting->writeEntry("HOST" + QString::number(i) + "e", QString());
+		setting->writeEntry("HOST" + QString::number(i) + "f", QString());
 	}
 
    // set the user toolbar list
@@ -869,28 +875,9 @@ void ClientWindow::sendTextToApp(const QString &txt)
 	static int store_games_sort_col = -1;
 #endif
 	static bool player7active = false;
-/*
 
-
-	// set codec
-	QString buf;
-	QTextStream t(&buf, IO_WriteOnly);
-	if (textCodec)
-		t.setCodec(textCodec);
-	QString tx = textFromHost;
-	t << tx;
-	QString txt;
-	if (!t.eof())
-		txt = t.read();
-qDebug("#" + buf);
-	if (txt == 0)
-	{
-		qDebug("##buffer empty");
-		return;
-	}
-//*/
 	// put text to parser
- 	InfoType it_ = parser->put_line(QString::fromLocal8Bit(txt));
+ 	InfoType it_ = parser->put_line(txt);
 
 	// some statistics
 	setBytesIn(txt.length()+2);
@@ -971,17 +958,17 @@ qDebug("#" + buf);
 					if (!ok)
 						set_sessionparameter("client", true);
 
-					// set quiet false; refresh players, games
+					// set quiet true; refresh players, games
 					//if (myAccount->get_status() == GUEST)
-					set_sessionparameter("quiet", false);
+					set_sessionparameter("quiet", true);
 					//else
 					// set id - only available if registerd; who knows why...
 					sendcommand("id qGo " + QString(VERSION), true);
 					sendcommand("toggle newrating");
 					sendcommand("toggle nmatch");
-					
+					sendcommand("toggle newundo");
 					//temporaary settings to prevent use of Koryo BY on IGS (as opposed to canadian)
-					sendcommand("nmatchrange BWN 0-9 19-19 60-6000 60-3600 25-25 0 0 0-0",false);
+					sendcommand("nmatchrange BWN 0-9 19-19 60-60 60-3600 25-25 0 0 0-0",false);
 					
 					sendcommand("toggle seek");
 					sendcommand("seek config_list ");
@@ -1045,6 +1032,9 @@ qDebug("#" + buf);
 				ListView_players->setSorting(store_sort_col);
 
 			store_sort_col = -1;
+
+			if (myAccount->get_gsname()==IGS)
+				ListView_players->showOpen(whoOpenCheck->isChecked());
 			ListView_players->sort();
 			playerListEmpty = false;
 			break;
@@ -1415,20 +1405,12 @@ void ClientWindow::slot_cbconnect(const QString &txt)
 	// inform telnet about selected host
 	QString lg = h->loginName();
 	QString pw = h->password();
-	telnetConnection->setHost(h->host(), lg, pw, h->port());
+	telnetConnection->setHost(h->host(), lg, pw, h->port(), h->codec());
 	if (toolConnect)
 	{
 		QToolTip::remove(toolConnect);
 		QToolTip::add(toolConnect, tr("Connect with") + " " + cb_connect->currentText());
 	}
-/*
-		// set up codec
-		qDebug("setting up codec...");
-//			QTextCodec *tc = textCodec;
-		textCodec = new QGbkCodec();
-		textStream->setEncoding(QTextStream::Locale);
-		textStream->setCodec(textCodec);
-//*/
 }
 
 // set checkbox status because of server info or because menu / checkbok toggled
@@ -1504,7 +1486,8 @@ void ClientWindow::slot_cbquiet()
 // switch between 'who' and 'user' cmds
 void ClientWindow::setColumnsForExtUserInfo()
 {
-	if (!extUserInfo || (myAccount->get_gsname() != IGS))
+	
+	if (!extUserInfo || (myAccount->get_gsname() != IGS) )
 	{
 		// set player table's columns to 'who' mode
 		ListView_players->removeColumn(11);
@@ -1513,7 +1496,7 @@ void ClientWindow::setColumnsForExtUserInfo()
 		ListView_players->removeColumn(8);
 		ListView_players->removeColumn(7);
 	}
-	else
+	else if ( ListView_players->columns()  < 9 )  
 	{
 		// set player table's columns to 'user' mode
 		// first: remove invisible column
@@ -1523,7 +1506,7 @@ void ClientWindow::setColumnsForExtUserInfo()
 		ListView_players->addColumn(tr("Won"));
 		ListView_players->addColumn(tr("Lost"));
 		ListView_players->addColumn(tr("Country"));
-		ListView_players->addColumn(tr("Lang"));
+		ListView_players->addColumn(tr("Match prefs"));
 		ListView_players->setColumnAlignment(7, AlignRight);
 		ListView_players->setColumnAlignment(8, AlignRight);
 		ListView_players->setColumnAlignment(9, AlignRight);
@@ -1586,6 +1569,8 @@ void ClientWindow::slot_updateFont()
 	}
 	viewStatusBar->setOn(setting->readBoolEntry("MAINSTATUSBAR"));
 
+	extUserInfo = setting->readBoolEntry("EXTUSERINFO");
+	setColumnsForExtUserInfo();
 //	slot_userDefinedKeysTextChanged();
 }
 
@@ -1601,30 +1586,30 @@ void ClientWindow::slot_refresh(int i)
 			prepare_tables(WHO);
 		case 0:
 			// send "WHO" command
-      //set the params of "who command"
-	if ((whoBox1->currentItem() >1)  || (whoBox2->currentItem() >1))
-        {
-		wparam.append(whoBox1->currentItem()==1 ? "9p" : whoBox1->currentText());
-		if ((whoBox1->currentItem())  && (whoBox2->currentItem()))
-			wparam.append("-");
-		wparam.append(whoBox2->currentItem()==1 ? "9p" : whoBox2->currentText());
-         } 
-	else if ((whoBox1->currentItem())  || (whoBox2->currentItem()))
-        	wparam.append("1p-9p");
-	else
-		wparam.append("all");
+      			//set the params of "who command"
+			if ((whoBox1->currentItem() >1)  || (whoBox2->currentItem() >1))
+        		{
+				wparam.append(whoBox1->currentItem()==1 ? "9p" : whoBox1->currentText());
+				if ((whoBox1->currentItem())  && (whoBox2->currentItem()))
+					wparam.append("-");
 
-      
-      if (whoOpenCheck->isChecked())
-          wparam.append(" o");
+				wparam.append(whoBox2->currentItem()==1 ? "9p" : whoBox2->currentText());
+         		} 
+			else if ((whoBox1->currentItem())  || (whoBox2->currentItem()))
+        			wparam.append("1p-9p");
+			else
+				wparam.append(((myAccount->get_gsname() == IGS) ? "9p-BC" : " "));
+				
 
-                  
-			if (myAccount->get_gsname() == IGS && extUserInfo)
-				sendcommand(wparam.prepend("user "));
+			if (whoOpenCheck->isChecked())
+				wparam.append(((myAccount->get_gsname() == WING) ? "O" : "o"));//wparam.append(" o");
+
+			if (myAccount->get_gsname() == IGS )//&& extUserInfo)
+				sendcommand(wparam.prepend("userlist "));
 			else
 				sendcommand(wparam.prepend("who "));
 
-      prepare_tables(WHO);
+      			prepare_tables(WHO);
 			break;
 
 		case 11:
@@ -1710,7 +1695,7 @@ void ClientWindow::slot_gamesPopup(int i)
 						g.FR = lv_popupGames->text(10);
 						g.ob = lv_popupGames->text(11);
 						g.running = true;
-            g.oneColorGo = false;
+            					g.oneColorGo = false;
             
 
 						emit signal_move(&g);
@@ -1783,7 +1768,7 @@ void ClientWindow::slot_mouse_games(int button, QListViewItem *lv, const QPoint&
 			{
 				//puw->move(pt);
 				//puw->show();
-        puw->popup( QCursor::pos() );
+        			puw->popup( QCursor::pos() );
 				// store selected lv
 				lv_popupGames = static_cast<GamesTableItem*>(lv);
 			}
@@ -1806,7 +1791,7 @@ void ClientWindow::slot_mouse_games(int button, QListViewItem *lv, const QPoint&
 }
 
 
-void ClientWindow::slot_matchCanceled(const QString &opponent)
+void ClientWindow::slot_removeMatchDialog(const QString &opponent)
 {
 	// set up match dialog
 	// match_dialog()
@@ -1820,14 +1805,13 @@ void ClientWindow::slot_matchCanceled(const QString &opponent)
 		dlg = matchlist.next();
 
 	if (dlg)
-    {
-    matchlist.remove();
-    delete dlg;
-    }
+	{
+    		matchlist.remove();
+    		delete dlg;
+    	}
 }   
 
 
-  
 void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 {
 	// set up match dialog
@@ -1870,10 +1854,19 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 				SLOT(slot_suggest(const QString&, const QString&, const QString&, const QString&, int)));
 		}
 		
+		connect(dlg,SIGNAL(signal_removeDialog(dlg)), this, SLOT(slot_removeDialog(dlg)));
+
 		connect(dlg,
 			SIGNAL(signal_sendcommand(const QString&, bool)),
 			this,
 			SLOT(slot_sendcommand(const QString&, bool)));
+
+		connect(dlg,
+			SIGNAL(signal_removeDialog(const QString&)),
+			this,
+			SLOT(slot_removeMatchDialog(const QString&)));
+
+
 		connect(parser,
 			SIGNAL(signal_matchcreate(const QString&, const QString&)),
 			dlg,
@@ -1890,6 +1883,11 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 			SIGNAL(signal_opponentopen(const QString&)),
 			dlg,
 			SLOT(slot_opponentopen(const QString&)));
+		connect(parser,
+			SIGNAL(signal_dispute(const QString&, const QString&)),
+			dlg,
+			SLOT(slot_dispute(const QString&, const QString&)));
+
 		connect(dlg,
 			SIGNAL(signal_matchsettings(const QString&, const QString&, const QString&, assessType)),
 			qgoif,
@@ -1913,7 +1911,8 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 		dlg->set_myRk(rk);
 		dlg->playerWhiteRkEdit->setText(rk);
 		dlg->set_gsName(myAccount->get_gsname());
-		
+		dlg->handicapSpin->setEnabled(false);
+
 		dlg->buttonDecline->setDisabled(true);
 
 		// my request: free/rated game is also requested
@@ -1923,11 +1922,30 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 		if (dlg->playerWhiteEdit->text() == dlg->playerBlackEdit->text())
 			dlg->buttonOffer->setText(tr("Teaching"));
 
+		//nmatch settings from opponent 
+		dlg->set_is_nmatch(lv_popupPlayer->nmatch);
+		if ( (lv_popupPlayer->nmatch) && (lv_popupPlayer->nmatch_settings ))
+		{
+			dlg->timeSpin->setRange((int)(lv_popupPlayer->nmatch_timeMin/60), (int)(lv_popupPlayer->nmatch_timeMax/60));
+			dlg->byoTimeSpin->setRange((int)(lv_popupPlayer->nmatch_BYMin/60), (int)(lv_popupPlayer->nmatch_BYMax/60));
+			dlg->handicapSpin->setRange(lv_popupPlayer->nmatch_handicapMin,lv_popupPlayer->nmatch_handicapMax);
+		}
+		else
+		{
+			dlg->timeSpin->setRange(0,60);
+			dlg->byoTimeSpin->setRange(0,60);
+			dlg->handicapSpin->setRange(0,9);
+		}
+		//no handicap with usual game requests
+		dlg->handicapSpin->setEnabled(lv_popupPlayer->nmatch);
+
 		//default settings
 		dlg->boardSizeSpin->setValue(setting->readIntEntry("DEFAULT_SIZE"));
 		dlg->timeSpin->setValue(setting->readIntEntry("DEFAULT_TIME"));
 		dlg->byoTimeSpin->setValue(setting->readIntEntry("DEFAULT_BY"));
 		dlg->komiSpin->setValue(setting->readIntEntry("DEFAULT_KOMI")*10+5);
+
+		dlg->slot_pbsuggest();
 	}
 	else
 	{
@@ -1938,21 +1956,21 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 		if (line.contains("nmatch"))
 		{
 			//specific behavior here : IGS nmatch not totally supported
-			// we don't want to enable disputes for the time being
+			// disputes are hardly supported
 			dlg->set_is_nmatch(true);
 			handicap = element(line,3 , " ");
 			size = element(line, 4, " ");
 			time = element(line, 5, " ");
 			byotime = element(line, 6, " ");
 			byostones = element(line, 7, " ");
-			dlg->timeSpin->setRange(time.toInt()/60,time.toInt()/60);
+			dlg->timeSpin->setRange(0,100);
 			dlg->timeSpin->setValue(time.toInt()/60);
-			dlg->byoTimeSpin->setRange(byotime.toInt()/60,byotime.toInt()/60);
+			dlg->byoTimeSpin->setRange(0,100);
 			dlg->byoTimeSpin->setValue(byotime.toInt()/60);
 			dlg->BY_label->setText(tr(" Byoyomi Time : (")+byostones+ tr(" stones)"));
-			dlg->handicapSpin->setRange(handicap.toInt(),handicap.toInt());
+			dlg->handicapSpin->setRange(0,9);
 			dlg->handicapSpin->setValue(handicap.toInt());
-			dlg->boardSizeSpin->setRange(size.toInt(),size.toInt());
+			dlg->boardSizeSpin->setRange(1,19);
 			dlg->boardSizeSpin->setValue(size.toInt());
 		}
 		else
@@ -2022,10 +2040,12 @@ void ClientWindow::slot_playerPopup(int i)
   
 	switch (i)
 	{
-		case 1:
+		case 1 :
+		case 11 :
 			// match
 			slot_matchrequest(player_name + " " + lv_popupPlayer->text(2), true);
-			break;
+			break;			
+
 
 		case 2:
     		case 3:
@@ -2224,12 +2244,13 @@ void ClientWindow::slot_menu_players(QListViewItem *lv, const QPoint& pt, int)
 void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoint& /*pt */, int /*column*/)
 {
 	static QPopupMenu *puw = 0;
-	
+	lv_popupPlayer = static_cast<PlayerTableItem*>(lv);
 	// create popup window
 	if (!puw)
 	{
 		puw = new QPopupMenu(0, 0);
 		puw->insertItem(tr("match"), this, SLOT(slot_playerPopup(int)), 0, 1);
+		puw->insertItem(tr("match within his prefs"), this, SLOT(slot_playerPopup(int)), 0, 11);
 		puw->insertItem(tr("talk"), this, SLOT(slot_playerPopup(int)), 0, 2);
 		puw->insertSeparator();
 		puw->insertItem(tr("stats"), this, SLOT(slot_playerPopup(int)), 0, 3);
@@ -2241,8 +2262,10 @@ void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoin
 		puw->insertItem(tr("toggle watch list"), this, SLOT(slot_playerPopup(int)), 0, 6);
 		puw->insertItem(tr("toggle exclude list"), this, SLOT(slot_playerPopup(int)), 0, 7);
 
-  }
-	//puw->hide();
+	}
+	
+	puw->setItemEnabled(11,lv_popupPlayer->nmatch);
+//puw->hide();
 
 	// do actions if button clicked on item
 	switch (button)
@@ -2264,7 +2287,7 @@ void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoin
 				puw->show();*/
         			puw->popup( QCursor::pos() );
 				// store selected lv
-				lv_popupPlayer = static_cast<PlayerTableItem*>(lv);
+				//lv_popupPlayer = static_cast<PlayerTableItem*>(lv);
 			}
 			break;
 
@@ -2273,7 +2296,7 @@ void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoin
 			if (lv)
 			{
 				// store selected lv
-				lv_popupPlayer = static_cast<PlayerTableItem*>(lv);
+				//lv_popupPlayer = static_cast<PlayerTableItem*>(lv);
 
 				slot_playerPopup(1);
 			}
@@ -2374,7 +2397,8 @@ void ClientWindow::slot_talk(const QString &name, const QString &text, bool ispl
 			dlg->get_mle()->setPalette(pal);
 			dlg->get_le()->setPalette(pal);
 			
-			if (!name.isEmpty() && name != tr("Shouts*") && currentCommand->get_txt() !="stats")
+			//if (!name.isEmpty() && name != tr("Shouts*") && currentCommand->get_txt() !="stats")
+			if (!name.isEmpty() && isplayer)
 				slot_sendcommand("stats " + name, false);    // automatically request stats
       
 		}
@@ -2828,6 +2852,7 @@ void ClientWindow::initActions()
 	connect(helpSoundInfo, SIGNAL(activated()), this, SLOT(slotHelpSoundInfo()));
 	connect(helpAboutApp, SIGNAL(activated()), this, SLOT(slotHelpAbout()));
 	connect(helpAboutQt, SIGNAL(activated()), this, SLOT(slotHelpAboutQt()));
+	connect(helpNewVersion, SIGNAL(activated()), this, SLOT(slotNewVersion()));
 }
   
 void ClientWindow::initToolBar()
@@ -2909,6 +2934,12 @@ void ClientWindow::slotHelpAboutQt()
 	QMessageBox::aboutQt(this);
 }
 
+void ClientWindow::slotNewVersion()
+{
+	QMessageBox::warning(this ,PACKAGE,NEWVERSIONWARNING);
+}
+
+
 void ClientWindow::slotFileNewBoard()
 {
 	setting->qgo->addBoardWindow();
@@ -2935,6 +2966,7 @@ void ClientWindow::slotFileOpen()
 
 void ClientWindow::slotComputerPlay()
 {
+#ifndef Q_OS_MACX
 	QString s =  setting->readEntry("COMPUTER_PATH");
 
 	if (setting->readEntry("COMPUTER_PATH").isNull() ||
@@ -2944,7 +2976,7 @@ void ClientWindow::slotComputerPlay()
 		qgoif->openPreferences(3);
 		return;
 	}
-
+#endif
 	QNewGameDlg * dlg = new QNewGameDlg(this);
 	if(!(dlg->exec()== QDialog::Accepted))
 		return;
