@@ -48,8 +48,9 @@
 #include <qtimer.h>
 #include <qpalette.h>
 #include <qtabwidget.h>
+#include <qlayout.h>
 
-#ifdef USE_XPM
+//#ifdef USE_XPM
 #include ICON_PREFS
 #include ICON_GAMEINFO
 #include ICON_EXIT
@@ -62,8 +63,8 @@
 #include ICON_CHARSET
 #include ICON_RIGHTARROW
 #include ICON_LEFTARROW
-#include ICON_RIGHTCOMMENT     //added eb 2
-#include ICON_LEFTCOMMENT       // end add eb 2
+#include ICON_RIGHTCOMMENT
+#include ICON_LEFTCOMMENT
 #include ICON_TWO_RIGHTARROW
 #include ICON_TWO_LEFTARROW
 #include ICON_NEXT_VAR
@@ -82,7 +83,10 @@
 #include ICON_MANUAL
 #include ICON_NAV_INTERSECTION
 #include ICON_COMPUTER_PLAY
-#endif
+#include ICON_COORDS
+#include ICON_SOUND_ON
+#include ICON_SOUND_OFF
+//#endif
 
 
 
@@ -165,7 +169,14 @@ MainWindow::MainWindow(QWidget* parent, const char* name, WFlags f)
 	// Connect the mouseMove event of the board with the status bar coords widget
 	connect(board, SIGNAL(coordsChanged(int, int, int,bool)), statusTip, SLOT(slotStatusTipCoords(int, int, int,bool)));
 	
-	commentEdit = new QTextEdit(splitter_comment, "comments");   //eb16
+	//commentEdit = new QTextEdit(splitter_comment, "comments");
+	QWidget *commentWidget = new QWidget(splitter_comment);
+	QVBoxLayout *commentLayout = new QVBoxLayout(commentWidget, 0,0,"commentLayout");
+	commentEdit = new QTextEdit(commentWidget,  "comments");
+	commentLayout->addWidget(commentEdit);
+	commentEdit2 = new QLineEdit( commentWidget, "commentEdit2" );
+	commentLayout->addWidget(commentEdit2);
+
 	ListView_observers = new QListView(splitter_comment, "observers");
 	splitter->setResizeMode(mainWidget, QSplitter::KeepSize);
 	splitter_comment->setResizeMode(ListView_observers, QSplitter::KeepSize);
@@ -180,7 +191,9 @@ MainWindow::MainWindow(QWidget* parent, const char* name, WFlags f)
 	ListView_observers->setSorting(-1);
 
 	commentEdit->setWordWrap(QTextEdit::WidgetWidth);
-	commentEdit2 = mainWidget->commentEdit2;
+	//commentEdit2 = mainWidget->commentEdit2;
+	//commentEdit2 = new QLineEdit( boardFrame, "commentEdit2" );
+
 	//    connect(commentEdit2, SIGNAL(returnPressed()), board, SLOT(modifiedComment()));
 	connect(commentEdit, SIGNAL(textChanged()), board, SLOT(updateComment()));
 	connect(commentEdit2, SIGNAL(returnPressed()), board, SLOT(updateComment2()));
@@ -348,8 +361,9 @@ void MainWindow::initActions()
 		nextCommentIcon, previousCommentIcon, navIntersectionIcon,
 		rightArrowIcon, leftArrowIcon,two_rightArrowIcon, two_leftArrowIcon,
 		prevVarIcon, nextVarIcon, startVarIcon,	mainBranchIcon, nextBranchIcon, autoplayIcon,
-		prefsIcon, infoIcon, increaseIcon, decreaseIcon, fullscreenIcon, manualIcon;
-#ifdef USE_XPM
+		prefsIcon, infoIcon, increaseIcon, decreaseIcon, fullscreenIcon, manualIcon,
+		coordsIcon, sound_onIcon, sound_offIcon;
+//#ifdef USE_XPM
 	prefsIcon = QPixmap(const_cast<const char**>(package_settings_xpm));
 	infoIcon = QPixmap(const_cast<const char**>(idea_xpm));
 	exitIcon = QPixmap(const_cast<const char**>(exit_xpm));
@@ -380,7 +394,10 @@ void MainWindow::initActions()
 	manualIcon = QPixmap(const_cast<const char**>(help_xpm));
 	autoplayIcon = QPixmap(const_cast<const char**>(player_pause_xpm));
 	navIntersectionIcon  = QPixmap(const_cast<const char**>(navIntersection_xpm));  //SL added eb 11
-  
+  	coordsIcon= QPixmap(const_cast<const char**>(coords_xpm)); 
+	sound_onIcon= QPixmap(const_cast<const char**>(sound_on_xpm)); 
+	sound_offIcon= QPixmap(const_cast<const char**>(sound_off_xpm)); 
+/*
 #else
 	prefsIcon = QPixmap(ICON_PREFS);
 	infoIcon = QPixmap(ICON_GAMEINFO);
@@ -411,16 +428,17 @@ void MainWindow::initActions()
 	fullscreenIcon = QPixmap(ICON_FULLSCREEN);
 	manualIcon = QPixmap(ICON_MANUAL);
 	autoplayIcon = QPixmap(ICON_AUTOPLAY);
-	navIntersectionIcon  = QPixmap(ICON_NAV_INTERSECTION);  //SL added eb 11
-
-  
+	navIntersectionIcon  = QPixmap(ICON_NAV_INTERSECTION);  
+	coordsIcon = QPixmap(ICON_COORDS);
+  	sound_onIcon = QPixmap(ICON_SOUND_ON);
+	sound_offIcon = QPixmap(ICON_SOUND_Off);
 #endif
-	
+*/	
 	/*
 	* Global actions
 	*/
 	// Escape focus: Escape key to get the focus from comment field to main window.
-	escapeFocus = new QAction(this);
+ 	escapeFocus = new QAction(this);
 	escapeFocus->setAccel(Key_Escape);
 	connect(escapeFocus, SIGNAL(activated()), this, SLOT(setFocus()));
 	
@@ -709,6 +727,19 @@ void MainWindow::initActions()
 	setGameInfo->setWhatsThis(tr("Game Info\n\nDisplay game information."));
 	connect(setGameInfo, SIGNAL(activated()), this, SLOT(slotSetGameInfo()));
 	
+	//Toggling sound
+	QIconSet  OIC;
+	OIC.setPixmap ( sound_offIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::On);
+	OIC.setPixmap ( sound_onIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::Off );
+	soundToggle = new QAction(tr("Mute stones sound"), OIC, tr("&Mute stones sound"),0, this,0,true);
+	soundToggle->setOn(!setting->readBoolEntry("SOUND_STONE"));
+	soundToggle->setStatusTip(tr("Toggle stones sound on/off"));
+	soundToggle->setWhatsThis(tr("Stones sound\n\nToggle stones sound on/off\nthis toggles only the stones sounds"));
+	connect(soundToggle, SIGNAL(toggled(bool)), this, SLOT(slotSoundToggle(bool)));
+	
+	
+
+
 	/*
 	* Menu View
 	*/
@@ -749,7 +780,7 @@ void MainWindow::initActions()
 	connect(viewStatusBar, SIGNAL(toggled(bool)), this, SLOT(slotViewStatusBar(bool)));
 	
 	// View Coordinates toggle
-	viewCoords = new QAction(tr("Coordinates"), tr("C&oordinates"),
+	viewCoords = new QAction(tr("Coordinates"),coordsIcon, tr("C&oordinates"),
 		QAccel::stringToKey(tr("F8")), this, 0, true);
 	viewCoords->setOn(false);
 	viewCoords->setStatusTip(tr("Enables/disables the coordinates"));
@@ -869,18 +900,18 @@ void MainWindow::initActions()
 	navSwapVariations->setEnabled(false);
 	navPrevComment->setEnabled(false);
 	navNextComment->setEnabled(false);
-  navIntersection->setEnabled(false);     //SL added eb 11
+  	navIntersection->setEnabled(false);     //SL added eb 11
 	editPaste->setEnabled(false);
 	editPasteBrother->setEnabled(false);
 }
 
 void MainWindow::initMenuBar()
 {
-#ifdef USE_XPM
+//#ifdef USE_XPM
 	QIconSet wtIcon(QPixmap(const_cast<const char**>(contexthelp_xpm)));
-#else
-	QIconSet wtIcon(QPixmap(ICON_WHATSTHIS));
-#endif
+//#else
+//	QIconSet wtIcon(QPixmap(ICON_WHATSTHIS));
+//#endif
 	
 	// submenu Import/Export
 	importExportMenu = new QPopupMenu();
@@ -951,6 +982,8 @@ void MainWindow::initMenuBar()
 	settingsMenu->insertTearOffHandle();
 	setPreferences->addTo(settingsMenu);
 	setGameInfo->addTo(settingsMenu);
+	settingsMenu->insertSeparator();
+	soundToggle->addTo(settingsMenu);
 	
 	// menuBar entry viewMenu
 	viewMenu = new QPopupMenu();
@@ -1029,6 +1062,12 @@ void MainWindow::initToolBar()
 	navAutoplay->addTo(toolBar);
 	
 	toolBar->addSeparator();
+
+	soundToggle->addTo(toolBar);
+	viewCoords->addTo(toolBar);
+
+	toolBar->addSeparator();
+
 	
 	QWhatsThis::whatsThisButton(toolBar);
 	
@@ -1556,6 +1595,7 @@ void MainWindow::dlgSetPreferences(int tab)
 //	dlg.styleListBox->setCurrentItem(setting->readIntEntry("STYLE"));
 //	dlg.woodListBox->setCurrentItem(setting->readIntEntry("SKIN"));
 	dlg.LineEdit_goban->setText(setting->readEntry("SKIN"));
+	dlg.LineEdit_Table->setText(setting->readEntry("SKIN_TABLE"));
 	dlg.languageComboBox->insertStringList(setting->getAvailableLanguages());
 	dlg.languageComboBox->setCurrentItem(setting->convertLanguageCodeToNumber());
 	dlg.commentComboBox->setCurrentItem(setting->readIntEntry("VIEW_COMMENT"));
@@ -1661,6 +1701,7 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 //	setting->writeIntEntry("STYLE", dlg->styleListBox->currentItem());
 //	setting->writeIntEntry("SKIN", dlg->woodListBox->currentItem());
 	setting->writeEntry("SKIN", dlg->LineEdit_goban->text()); 
+	setting->writeEntry("SKIN_TABLE", dlg->LineEdit_Table->text()); 
 	setting->writeEntry("LANG", setting->convertNumberToLanguage(dlg->languageComboBox->currentItem()));
 	setting->writeIntEntry("VIEW_COMMENT", dlg->commentComboBox->currentItem());
 	setting->writeBoolEntry("STONES_SHADOW", dlg->stonesShadowCheckBox->isChecked());
@@ -1736,7 +1777,7 @@ void MainWindow::updateBoard()
 	viewCoords->setOn(setting->readBoolEntry("BOARD_COORDS"));
 	board->setShowSGFCoords(setting->readBoolEntry("SGF_BOARD_COORDS"));
 	board->set_antiClicko(setting->readBoolEntry("ANTICLICKO"));
-//	viewComment->setOn(setting->readIntEntry("VIEW_COMMENT"));
+	viewComment->setOn(setting->readIntEntry("VIEW_COMMENT"));
 
 	if (setting->readIntEntry("VIEW_COMMENT"))
 	{
@@ -1767,7 +1808,7 @@ void MainWindow::updateBoard()
 bool MainWindow::preferencesAccept()
 {
 	// Interface tab
-	setApplicationStyle();
+	//setApplicationStyle();
 
 	// Update all boards with settings
 	setting->qgo->updateAllBoardSettings();
@@ -1906,7 +1947,7 @@ void MainWindow::slotViewSlider(bool toggle)
 
 void MainWindow::slotViewComment(bool toggle)
 {
-//	setting->writeIntEntry("VIEW_COMMENT", toggle ? viewVertComment->isOn() ? 2 : 1 : 0);
+	setting->writeIntEntry("VIEW_COMMENT", toggle ? viewVertComment->isOn() ? 2 : 1 : 0);
 	if (!toggle)
 	{
 		commentEdit->hide();
@@ -1933,7 +1974,7 @@ void MainWindow::slotViewComment(bool toggle)
 
 void MainWindow::slotViewVertComment(bool toggle)
 {
-//	setting->writeIntEntry("VIEW_COMMENT", toggle ? 2 : 1);
+	setting->writeIntEntry("VIEW_COMMENT", toggle ? 2 : 1);
 	splitter->setOrientation(toggle ? Horizontal : Vertical);
 	splitter->setResizeMode(mainWidget, QSplitter::KeepSize);
 	splitter_comment->setOrientation(!toggle ? Horizontal : Vertical);
@@ -2133,7 +2174,7 @@ void MainWindow::slotTimerForward()
 		statusBar()->message(tr("Autoplay stopped."));
 	}
 }
-
+/*
 void MainWindow::setApplicationStyle()
 {
 	if (setting->readIntEntry("STYLE") < 0 || setting->readIntEntry("STYLE") > 6)
@@ -2174,7 +2215,7 @@ void MainWindow::setApplicationStyle()
 		qWarning("Unrecognized style!");
 	}
 }
-
+*/
 // store and restore window properties
 bool MainWindow::reStoreWindowSize(QString strKey, bool store)
 {
@@ -2503,4 +2544,10 @@ void MainWindow::addObserver(const QString &name)
 //	ListView_observer->addItem
 }
 
+void MainWindow::slotSoundToggle(bool toggle)
+{
+	board->getBoardHandler()->local_stone_sound = !toggle ;
+}
+
+
 
