@@ -7,6 +7,7 @@
 #include "qgo.h"
 #include "setting.h"
 #include <qpainter.h>
+//#include <qpixmap.h>
 
 /*
 * Mark
@@ -210,6 +211,13 @@ MarkText::MarkText(ImageHandler *ih, int x, int y, int size, const QString &txt,
 	setSize(size, size);
 	setColor(col);
 	
+	QPixmap * pix = new QPixmap(width, height);
+	pix->fill(Qt::white);
+	//bitBlt((QPaintDevice *)(pix),0,0,(QPaintDevice *)(ih->getBoardPixmap(setting->readEntry("SKIN"))),x,y,width,height,Qt::CopyROP);
+	//bitBlt((QPaintDevice *)(pix),0,0,(QPaintDevice *)(ih->getTablePixmap(setting->readEntry("SKIN_TABLE"))),x,y,5,5,Qt::CopyROP,false);
+	copyBlt(pix,0,0,ih->getTablePixmap(setting->readEntry("SKIN_TABLE")),size * (x-1) - width/2,size * (y-1) - height/2,8,8);
+	//pix.fill((QWidget *)(canvas), x,y);
+	
 	if (overlay)
 	{
 	
@@ -223,9 +231,12 @@ MarkText::MarkText(ImageHandler *ih, int x, int y, int size, const QString &txt,
 		CHECK_PTR(rect);
 		rect->setPen(NoPen);
 		CHECK_PTR(ih);
+		rect->setSize(width, height);
+		//rect->setX(size * (x-1) - width/2);
+		//rect->setX(size * (y-1) - height/2);
 		//rect->setBrush(QBrush(white, *(ih->getBoardPixmap(static_cast<skinType>(setting->readIntEntry("SKIN"))))));
 		rect->setBrush(QBrush(white, *(ih->getBoardPixmap(setting->readEntry("SKIN")))));
-		rect->setSize(width, height);
+		
 		rect->setZ(1);
 		rect->show();
 	}
