@@ -4,9 +4,9 @@
 
 #include "parser.h"
 #include "qgo_interface.h"
+#include "tables.h"
 #include <qregexp.h>
 
-
 // Parsing of Go Server messages
 Parser::Parser() : QObject(), Misc<QString>()
 {
@@ -225,7 +225,7 @@ InfoType Parser::put_line(const QString &txt)
 			if (memory_str && (memory_str.contains("File")||memory_str.contains("STATS")))
 				// if ready this cannont be a help message
 				memory_str = QString();
-      emit signal_message("\n");  
+			emit signal_message("\n");  
 			return READY;
 			break;
 
@@ -241,6 +241,8 @@ InfoType Parser::put_line(const QString &txt)
 		// ERROR message
 		//	5 Player "xxxx" is not open to match requests.
 		//	5 You cannot observe a game that you are playing.
+		//	5 You cannot undo in this game
+		//	5 Opponent's client does not support undoplease
 		case 5:
 			if (line.contains("No user named"))
 			{
@@ -258,9 +260,41 @@ InfoType Parser::put_line(const QString &txt)
 				emit signal_notopen(0);
 			}
 
+			else if (line.contains("You cannot undo") || line.contains("client does not support undoplease")) 
+			{
+				// not the cleanest way : we should send this to a messagez box
+				emit signal_kibitz(0, 0, line);
+				return KIBITZ;
+			}
+
+	// Debug: 5 There is a dispute regarding your match(nmatch):
+	// Debug: 5 yfh2test request: B 3 19 420 900 25 0 0 0
+	// Debug: 5 yfh22 request: W 3 19 600 900 25 0 0 0
+
+			else if (line.contains("request:"))// && (element(line, 0, " ") != myname))
+			{
+				QString p = element(line, 0, " ");
+				if (p == myname)
+				{
+					memory_str = line ;
+					return MESSAGE;
+				}
+				
+				if (memory_str.contains(myname + " request"))
+				{
+					memory_str = "";
+					return MESSAGE;
+				}
+
+				QString nmatch_dispute = element(line, 1, " ", "EOL");				
+				
+				emit signal_dispute(p, nmatch_dispute);
+				return MESSAGE;
+			}
+
 			emit signal_message(line);
 
-			return MESSAGE;
+			return  MESSAGE;
 			break;
 			
 		// games
@@ -633,6 +667,19 @@ InfoType Parser::put_line(const QString &txt)
 				QString opp = element(line, 0, " ");
 				emit signal_notopen(opp);
 			}
+			//9 yfh2test declines undo
+			else if (line.contains("declines undo"))
+			{
+				// not the cleanest way : we should send this to a message box
+				emit signal_kibitz(0, element(line, 0, " "), line);
+				return KIBITZ;
+			}
+		
+			//9 yfh2test left this room
+			//9 yfh2test entered this room
+			else if (line.contains("this room"))
+				emit signal_refresh(10);				
+
 			//9 Requesting match in 10 min with frosla as Black.
 			else if (line.contains("Requesting match in"))
 			{
@@ -842,12 +889,12 @@ qDebug("parser->case 9: Use adjourn to");
 				aPlayer->won = "";
 				aPlayer->lost = "";
 				aPlayer->country = "";
-				aPlayer->language = "";
+				aPlayer->nmatch_settings = "";
 
 				// remove cmd nr
-				line = txt.stripWhiteSpace();
-				line = line.remove(0, 2);
-				emit signal_message(line);
+				//line = txt.stripWhiteSpace();
+				//line = line.remove(0, 2);
+				//emit signal_message(line);
 				return PLAYER42_END;
 			}
 			// 9 qGoDev has resigned the game.
@@ -900,7 +947,7 @@ qDebug("parser->case 9: Use adjourn to");
 	statsPlayer->won = "";
 	statsPlayer->lost = "";
 	statsPlayer->country = "";
-	statsPlayer->language = "";
+	statsPlayer->nmatch_settings = "";
 	statsPlayer->rank = "";
 	statsPlayer->info = "";
         statsPlayer->address = "";
@@ -1404,9 +1451,10 @@ qDebug("parser->case 9: Use adjourn to");
 //TODO			break;
 
 		//  24 *xxxx*: CLIENT: <cgoban 1.9.12> match xxxx wants handicap 0, komi 5.5, free
-		//	24 *jirong*: CLIENT: <cgoban 1.9.12> match jirong wants handicap 0, komi 0.5
-    //  24 *SYSTEM*: shoei canceled the nmatch request.
-    
+		//  24 *jirong*: CLIENT: <cgoban 1.9.12> match jirong wants handicap 0, komi 0.5
+    		//  24 *SYSTEM*: shoei canceled the nmatch request.
+		//  24 *SYSTEM*: xxx requests undo.
+
 		// NNGS - new version:
 		//  24 --> frosla CLIENT: <qGo 0.0.15b7> match frosla wants handicap 0, komi 0.5, free
 		//  24 --> frosla  Hallo
@@ -1446,17 +1494,21 @@ qDebug("parser->case 9: Use adjourn to");
 				return TELL;
 			}
       
-      //check for cancelled game offer
-      if (line.contains("*SYSTEM*"))
-      {
-       QString opp = element(line, 1, " ");
-       line = line.remove(0,10);
-       emit signal_message(line);
+      			//check for cancelled game offer
+			if (line.contains("*SYSTEM*"))
+			{
+				QString opp = element(line, 1, " ");
+				line = line.remove(0,10);
+				emit signal_message(line);
 
-       if  (line.contains("canceled") &&  line.contains("match request"))
-        emit signal_matchCanceled(opp);
-       return IT_OTHER ;
-      }
+				if  (line.contains("canceled") &&  line.contains("match request"))
+					emit signal_matchCanceled(opp);
+
+				if  (line.contains("requests undo"))
+					emit signal_requestDialog("undo","noundo",0,opp);
+
+				return IT_OTHER ;
+			}
       
 			// check for NNGS type of msg
 			QString e1,e2;
@@ -1486,8 +1538,8 @@ qDebug("parser->case 9: Use adjourn to");
     //25 File
 		case 25:
 		{
-      break;
-    }
+      			break;
+    		}
 		// who
 		case 27:
 		{
@@ -1619,6 +1671,7 @@ qDebug("parser->case 9: Use adjourn to");
 					aPlayer->play_str = txt.mid(11,3).stripWhiteSpace();
 					aPlayer->name = txt.mid(15,11).stripWhiteSpace();
 					aPlayer->idle = txt.mid(26,3);
+					aPlayer->nmatch = false;
 					if (txt[33] == ' ')
 					{
 						if (txt[36] == ' ')
@@ -1651,6 +1704,7 @@ qDebug("parser->case 9: Use adjourn to");
 					aPlayer->play_str = txt.mid(48,3).stripWhiteSpace();
 					aPlayer->name = txt.mid(52,11).stripWhiteSpace();
 					aPlayer->idle = txt.mid(63,3);
+					aPlayer->nmatch = false;
 					if (txt[70] == ' ')
 					{
 						if (txt[73] == ' ')
@@ -1729,12 +1783,17 @@ qDebug("parser->case 9: Use adjourn to");
 		// channel talk: "49:xxxx: hi"
 		case 32:
 		{
-			// skip welcome message of IGS
+			
+			QString e1,e2;
+			
 			if (line.contains("Changing into channel"))
 			{
-				int nr = element(line, 3, " ").toInt();
+				e1 = element(line, 2, " ",".");
+				int nr = e1.toInt();//element(line, 3, " ").toInt();
 				emit signal_channelinfo(nr, QString("*on*"));
-				emit signal_message(line);
+				emit signal_talk(e1, "", false);
+				//emit signal_message(line);
+				
 				break;
 			}
 			else if (line.contains("Welcome to cyberspace"))
@@ -1755,8 +1814,8 @@ qDebug("parser->case 9: Use adjourn to");
 				break;
 			}
 
-			// emit player + message + false (=channel)
-			QString e1,e2;
+			// emit (channel number, player + message , false =channel )
+			
 			switch (gsName)
 			{
 				case IGS:
@@ -1805,6 +1864,14 @@ qDebug("parser->case 9: Use adjourn to");
 		// 42   Beholder  <None>          Germany   NR    0/   0 263  -    5s    QX default 
 		// 42     xiejun  1/10-15         Germany   3d* 485/ 414 179  -   49s    -X default
 		// 9                 ******** 1120 Players 247 Total Games ********
+
+		// IGS: new cmd 'userlist' for nmatch information
+		//          10        20        30        40        50        60        70        80        80        90       100       110       120
+		// 01234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789
+		// 42 Name        Info            Country  Rank Won/Lost Obs  Pl Idle Flags Language
+		// 42      -----  <none>          Japan    15k+ 2108/2455  -   -    1m    Q- default  T BWN 0-9 19-19 600-600 1200-1200 25-25 0-0 0-0 0-0
+		// 42      -----           Japan     3d   11/  13  -  222  46s    Q- default  T BWN 0-9 19-19 60-60 600-600 25-25 0-0 0-0 0-0
+		// 42       Neil  <None>          USA      12k  136/  86  -   -    0s    -X default  T BWN 0-9 19-19 60-60 60-3600 25-25 0-0 0-0 0-0
 		case 42:
 		{
 			if (txt[40] == 'R')
@@ -1812,55 +1879,110 @@ qDebug("parser->case 9: Use adjourn to");
 				// skip
 				return PLAYER42_START;
 			}
+			//                        1                   2
+			//                        Name                Info
+			QRegExp re = QRegExp("42 ([A-Za-z0-9 ]{,10})  (.{1,14})  "
+			//                    3
+			//                    Country
+			                     "([a-zA-Z][a-zA-Z. /]{,6}|--     )  "
+			//                    4
+			//                    Rank
+			                     "([0-9 ][0-9][kdp].?| +BC) +"
+			//                    5               6
+			//                    Won             Lost
+			                     "([0-9 ]+[0-9]+)/([0-9 ]+[0-9]+) +"
+			//                    7           8
+			//                    Obs         Pl
+			                     "([0-9]+|-) +([0-9]+|-) +"
+			//                    9               10                   11    12
+			//                    Idle            Flags
+			                     "([A-Za-z0-9]+) +([^ ]{,2}) +default  ([TF])(.*)?");
+			if(re.match(txt) < 0)
+			{
+				qDebug("%s\n", txt.utf8().data());
+				qDebug("No match\n");
+				break;
+			}
+			// 42       Neil  <None>          USA      12k  136/  86  -   -    0s    -X default  T BWN 0-9 19-19 60-60 60-3600 25-25 0-0 0-0 0-0
 
-			// parse line
-			if (txt[40] == ' ')
-			{
-				if (txt[43] == ' ')
-					aPlayer->rank = txt.mid(41,2);
-				else
-					aPlayer->rank = txt.mid(41,3);
-			}
-			else
-			{
-				if (txt[43] == ' ')
-					aPlayer->rank = txt.mid(40,3);
-				else
-					aPlayer->rank = txt.mid(40,4);
-			}
-			aPlayer->name = txt.mid(3,10).stripWhiteSpace();
-			aPlayer->country = txt.mid(31,8).stripWhiteSpace();
-			if (aPlayer->country.contains("--"))
-				aPlayer->country = "";
-			aPlayer->idle = txt.mid(62,4).stripWhiteSpace();
-			aPlayer->extInfo = txt.mid(15,14).stripWhiteSpace().leftJustify(14, ' ');
+			aPlayer->name = re.cap(1).stripWhiteSpace();
+			aPlayer->extInfo = re.cap(2);
+			aPlayer->country = re.cap(3).stripWhiteSpace();
+			if(aPlayer->country == "--")
+			aPlayer->country = "";
+			aPlayer->rank = re.cap(4).stripWhiteSpace();
+			aPlayer->won = re.cap(5).stripWhiteSpace();
+			aPlayer->lost = re.cap(6).stripWhiteSpace();
+			aPlayer->obs_str = re.cap(7).stripWhiteSpace();
+			aPlayer->play_str = re.cap(8).stripWhiteSpace();
+			aPlayer->idle = re.cap(9).stripWhiteSpace();
+			aPlayer->info = re.cap(10).stripWhiteSpace();
+			aPlayer->nmatch = re.cap(11) == "T";
 
-			// maybe there's a shift...
-			if (txt[49] == '/')
-			{
-				// yes, shift right
-				aPlayer->info = txt.mid(71,2);
-				aPlayer->obs_str = txt.mid(55,3);
-				aPlayer->play_str = txt.mid(59,3);
-				aPlayer->won = txt.mid(45,4);
-				aPlayer->lost = txt.mid(50,4).stripWhiteSpace();
-				if (txt.mid(73,8).contains("default"))
-					aPlayer->language = "";
-				else
-					aPlayer->language = txt.mid(73,8).stripWhiteSpace();
-			}
-			else
-			{
-				// no shift
-				aPlayer->info = txt.mid(70,2);
-				aPlayer->obs_str = txt.mid(54,3);
-				aPlayer->play_str = txt.mid(58,3);
-				aPlayer->won = txt.mid(45,3).stripWhiteSpace();
-				aPlayer->lost = txt.mid(49,4).stripWhiteSpace();
-				if (txt.mid(72,8).contains("default"))
-					aPlayer->language = "";
-				else
-					aPlayer->language = txt.mid(72,8).stripWhiteSpace();
+			aPlayer->nmatch_settings = "";
+			QString nmatchString = "";
+			// we want to format the nmatch settings to a readable string
+			if (aPlayer->nmatch)
+			{	
+				// BWN 0-9 19-19 60-60 600-600 25-25 0-0 0-0 0-0
+				nmatchString = re.cap(12);
+				if ( ! nmatchString.isEmpty())
+				{
+					
+					aPlayer->nmatch_black = (nmatchString.contains("B"));
+					aPlayer->nmatch_white = (nmatchString.contains("W"));
+					aPlayer->nmatch_nigiri = (nmatchString.contains("N"));					
+	
+					aPlayer->nmatch_timeMin = element(nmatchString, 2, " ", "-").toInt();
+					aPlayer->nmatch_timeMax = element(nmatchString, 2, "-", " ").toInt();
+					QString t1min = QString::number(aPlayer->nmatch_timeMin / 60);
+					QString t1max = QString::number(aPlayer->nmatch_timeMax / 60);
+					if (t1min != t1max)
+						t1min.append(" to ").append(t1max) ;
+					
+					QString t2min = element(nmatchString, 3, " ", "-");
+					QString t2max = element(nmatchString, 3, "-", " ");
+					aPlayer->nmatch_BYMin = t2min.toInt();
+					aPlayer->nmatch_BYMax = t2max.toInt();
+
+					QString t3min = QString::number(t2min.toInt() / 60);
+					QString t3max = QString::number(t2max.toInt() / 60);
+
+					if (t2min != t2max)
+						t2min.append(" to ").append(t2max) ;
+
+					if (t3min != t3max)
+						t3min.append(" to ").append(t3max) ;
+
+					QString s1 = element(nmatchString, 4, " ", "-");
+					QString s2 = element(nmatchString, 4, "-", " ");
+					aPlayer->nmatch_stonesMin = s1.toInt();
+					aPlayer->nmatch_stonesMax = s2.toInt();
+					
+					if (s1 != s2)
+						s1.append("-").append(s2) ;
+					
+					if (s1 == "1") 
+						aPlayer->nmatch_settings = "Jap. BY : " +
+						t1min + " min. + " +
+						t2min + " secs./st. " ;
+					else
+						aPlayer->nmatch_settings = "Can. BY : " +
+							t1min + " min. + " +
+							t3min + " min. /" +
+							s1 + " st. ";
+
+					QString h1 = element(nmatchString, 0, " ", "-");
+					QString h2 = element(nmatchString, 0, "-", " ");
+					aPlayer->nmatch_handicapMin = h1.toInt();
+					aPlayer->nmatch_handicapMax = h2.toInt();
+					if (h1 != h2)
+						h1.append("-").append(h2) ;
+					
+					aPlayer->nmatch_settings.append("(h " + h1 + ")") ;
+				}
+				else 
+					aPlayer->nmatch_settings = "No match conditions";
 			}
 
 			// indicate player to be online
