@@ -58,6 +58,9 @@ signals:
 	void signal_clearSeekCondition();
 	void signal_cancelSeek();
 	void signal_SeekList(const QString&, const QString&);
+	void signal_refresh(int);
+	void signal_dispute(const QString&, const QString&);
+	//void signal_undoRequest(const QString&);
 
 public:
 	Parser();
