@@ -17,6 +17,7 @@
 #include <qpalette.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
+#include <qtextcodec.h>
 #include <stdlib.h>
 #include <time.h>
 #include <qvalidator.h>
@@ -26,6 +27,11 @@
 #include <qtoolbutton.h>
 #include <qobjectlist.h>
 
+#ifdef Q_OS_MACX
+#include <CoreFoundation/CFString.h>
+#include <CoreFoundation/CFBundle.h>
+#endif //Q_OS_MACX
+
 /* 
 *  Constructs a PreferencesDialog which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
@@ -110,9 +116,19 @@ PreferencesDialog::PreferencesDialog(QWidget* parent,  const char* name, bool mo
 	pal.setColor(QColorGroup::Button, setting->colorBackground);
 	colorBackgroundButton->setPalette(pal);
 
+	pal = colorAltBackgroundButton->palette();
+	pal.setColor(QColorGroup::Button, setting->colorAltBackground);
+	colorAltBackgroundButton->setPalette(pal);
+
 #ifdef QGO_NOSTYLES
 	styleListBox->setDisabled(true);
 #endif
+
+	// Default codec
+	ComboBox_codec->insertItem("");
+	// The rest by name
+	for(int i = 0; QTextCodec *codec = QTextCodec::codecForIndex(i); ++i)
+		ComboBox_codec->insertItem(codec->name());
 }
 
 /*  
@@ -228,6 +244,21 @@ void PreferencesDialog::selectColor()
 	}
 }
 
+void PreferencesDialog::selectAltColor()
+{
+	// Open a font dialog to select a new font
+	QColor c = QColorDialog::getColor(setting->colorAltBackground, this);
+	if (c.isValid())  // Accepted
+	{
+		setting->colorAltBackground = c;
+
+		// set button color
+		QPalette pal = colorAltBackgroundButton->palette();
+		pal.setColor(QColorGroup::Button, setting->colorAltBackground);
+		colorAltBackgroundButton->setPalette(pal);
+	}
+}
+
 void PreferencesDialog::slot_accept()
 {
 	saveSizes();
@@ -297,7 +328,8 @@ void PreferencesDialog::slot_add()
 				LineEdit_host->text(),
 				tmp,
 				LineEdit_login->text(),
-				LineEdit_pass->text()));
+				LineEdit_pass->text(),
+				ComboBox_codec->currentText()));
 		// create entry in listview
 		if (!found)
 			new QListViewItem(ListView_hosts,
@@ -390,6 +422,7 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->clear();
 		LineEdit_port->clear();
 		LineEdit_login->clear();
+		ComboBox_codec->setCurrentText("");
 	}
 	// fix coding: standard servers
 	else if (txt == QString("-- Aurora --"))
@@ -398,6 +431,8 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("aurora.go.art.pl");
 		LineEdit_port->setText("9696");
 		LineEdit_login->setText("guest");
+		// What codec does this use?
+		ComboBox_codec->setCurrentText("");
 	}
 	else if (txt == QString("-- CTN --"))
 	{
@@ -405,6 +440,8 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("weiqi.online.sh.cn");
 		LineEdit_port->setText("8888");
 		LineEdit_login->setText("guest");
+		// What codec does this use?
+		ComboBox_codec->setCurrentText("");
 	}
 	else if (txt == QString("-- CWS --"))
 	{
@@ -412,6 +449,8 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("cws.weiqi.net");
 		LineEdit_port->setText("9696");
 		LineEdit_login->setText("qGo" + QString::number(rand() % 10000));
+		// What codec does this use?
+		ComboBox_codec->setCurrentText("");
 	}
 	else if (txt == QString("-- LGS --"))
 	{
@@ -419,6 +458,8 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("lgs.taiwango.net");
 		LineEdit_port->setText("9696");
 		LineEdit_login->setText("guest");
+		// What codec does this use?
+		ComboBox_codec->setCurrentText("");
 	}
 	else if (txt == QString("-- WING --"))
 	{
@@ -426,6 +467,8 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("wing.gr.jp");
 		LineEdit_port->setText("1515");
 		LineEdit_login->setText("guest");
+		// What codec does this use?
+		ComboBox_codec->setCurrentText("");
 	}
 	else if (txt == QString("-- IGS --"))
 	{
@@ -433,6 +476,7 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("igs.joyjoy.net");
 		LineEdit_port->setText("7777");
 		LineEdit_login->setText("guest");
+		ComboBox_codec->setCurrentText("SJIS");
 	}
 	else if (txt == QString("-- NNGS --"))
 	{
@@ -440,6 +484,8 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("nngs.cosmic.org");
 		LineEdit_port->setText("9696");
 		LineEdit_login->setText("qGo" + QString::number(rand() % 10000));
+		// A guess
+		ComboBox_codec->setCurrentText("iso-8859-1");
 	}
 	else if (txt == QString("-- EGF --"))
 	{
@@ -447,6 +493,8 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 		LineEdit_host->setText("server.european-go.org");
 		LineEdit_port->setText("6969");
 		LineEdit_login->setText("qGo" + QString::number(rand() % 10000));
+		// A guess
+		ComboBox_codec->setCurrentText("iso-8859-15");
 	}
 	else if (!txt.isEmpty())
 	{
@@ -462,6 +510,7 @@ void PreferencesDialog::slot_cbtitle(const QString &txt)
 				LineEdit_port->setText(QString::number(h->port()));
 				LineEdit_login->setText(h->loginName());
 				LineEdit_pass->setText(h->password());
+				ComboBox_codec->setCurrentText(h->codec());
 				found = true;
 			}
 
@@ -531,7 +580,18 @@ void PreferencesDialog::slot_getComputerPath()
 
 void PreferencesDialog::slot_getGobanPicturePath()
 {
-	QString fileName(QFileDialog::getOpenFileName(setting->readEntry("LAST_DIR"),
+#ifdef Q_OS_MACX
+	// On the Mac, we want to default this dialog to the directory in the bundle
+	// that contains the wood images we ship with the app
+	//get the bundle path and find our resources
+	CFURLRef bundleRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
+	CFStringRef bundlePath = CFURLCopyFileSystemPath(bundleRef, kCFURLPOSIXPathStyle);
+	QString path = (QString)CFStringGetCStringPtr(bundlePath, CFStringGetSystemEncoding())
+		+ "/Contents/Resources/Backgrounds";
+#else
+	QString path = setting->readEntry("LAST_DIR");
+#endif
+	QString fileName(QFileDialog::getOpenFileName(path,
 		tr("Images (*.png *.xpm *.jpg)"), this));
 	if (fileName.isEmpty())
 		return;
@@ -539,6 +599,26 @@ void PreferencesDialog::slot_getGobanPicturePath()
   	LineEdit_goban->setText(fileName);
 }
 
+void PreferencesDialog::slot_getTablePicturePath()
+{
+#ifdef Q_OS_MACX
+	// On the Mac, we want to default this dialog to the directory in the bundle
+	// that contains the wood images we ship with the app
+	//get the bundle path and find our resources
+	CFURLRef bundleRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
+	CFStringRef bundlePath = CFURLCopyFileSystemPath(bundleRef, kCFURLPOSIXPathStyle);
+	QString path = (QString)CFStringGetCStringPtr(bundlePath, CFStringGetSystemEncoding())
+		+ "/Contents/Resources/Backgrounds";
+#else
+	QString path = setting->readEntry("LAST_DIR");
+#endif
+	QString fileName(QFileDialog::getOpenFileName(path,
+		tr("Images (*.png *.xpm *.jpg)"), this));
+	if (fileName.isEmpty())
+		return;
+
+  	LineEdit_Table->setText(fileName);
+}
 
 void PreferencesDialog::slot_getPixmapPath()
 {
@@ -575,61 +655,60 @@ void PreferencesDialog::slot_new_button()
 // button "add" clicked or "ok" pressed
 void PreferencesDialog::slot_add_button()
 {
-  QToolButton *b,*b0;
-  QObjectList *bl = parent_cw->UserToolbar->queryList( "QToolButton" ,NULL,true,false);
-  bool found = false;
-  // check if at least title and host inserted
+	QToolButton *b,*b0;
+	QObjectList *bl = parent_cw->UserToolbar->queryList( "QToolButton" ,NULL,true,false);
+	bool found = false;
+	// check if at least title and host inserted
 	if (!LineEdit_label->text().isEmpty() && !LineEdit_command->text().isEmpty())
 	{
-    // check if label already exists
+	// check if label already exists
 
-	  for ( b0 = (QToolButton*)bl->first(); (b0 != 0) && !found; b0 = (QToolButton*)bl->next())
+		for ( b0 = (QToolButton*)bl->first(); (b0 != 0) && !found; b0 = (QToolButton*)bl->next())
 		{
-      if (b0->textLabel() == LineEdit_label->text())
+      			if (b0->textLabel() == LineEdit_label->text())
 			{
 				found = true;
 				// if found, remove old item
 				parent_cw->userButtonGroup->remove(b0);
-        delete b0;
+				delete b0;
 			}  
 		}
 
-    QPixmap p;
+		QPixmap p;
 
-    b=new QToolButton(parent_cw->UserToolbar) ;
-    b->setTextLabel(LineEdit_label->text());   //label of the button
-    b->setText(LineEdit_label->text());
-    b->setCaption(LineEdit_command->text()); //dirty but handy
-    b->setIconText(LineEdit_pixfile->text()); //dirty also but handy
-    QToolTip::add(b,LineEdit_help->text());
-    b->setMinimumWidth(25);
-   
-   if ( p.load(LineEdit_pixfile->text()))
-      b->setPixmap(p);  
-    parent_cw->userButtonGroup->insert(b,-1);
-    
+		b=new QToolButton(parent_cw->UserToolbar) ;
+		b->setTextLabel(LineEdit_label->text());   //label of the button
+		b->setText(LineEdit_label->text());
+		b->setCaption(LineEdit_command->text()); //dirty but handy
+		b->setIconText(LineEdit_pixfile->text()); //dirty also but handy
+		QToolTip::add(b,LineEdit_help->text());
+		b->setMinimumWidth(25);
 
-   if (!found)
-    {
-      QListViewItem *buttonItem = new QListViewItem(ListView_buttons,
-				"",
-				LineEdit_label->text(),
-				LineEdit_command->text(),
-				LineEdit_help->text(),
-        LineEdit_pixfile->text());   
-        buttonItem->setPixmap(0,p);
-    }
-   else
-    {
+		if ( p.load(LineEdit_pixfile->text()))
+			b->setPixmap(p);
+  
+		parent_cw->userButtonGroup->insert(b,-1);
+
+		if (!found)
+		{
+			QListViewItem *buttonItem = new QListViewItem(ListView_buttons,
+					"",
+					LineEdit_label->text(),
+					LineEdit_command->text(),
+					LineEdit_help->text(),
+			LineEdit_pixfile->text());   
+			buttonItem->setPixmap(0,p);
+		}
+		else
+		{
 			ListView_buttons->currentItem()->setText(1, LineEdit_label->text());
 			ListView_buttons->currentItem()->setText(2, LineEdit_command->text());
 			ListView_buttons->currentItem()->setText(3, LineEdit_help->text());
 			ListView_buttons->currentItem()->setText(4, LineEdit_pixfile->text());
-      ListView_buttons->currentItem()->setPixmap(0,p);
-    }
-
-  }
-  slot_new_button();    
+			ListView_buttons->currentItem()->setPixmap(0,p);
+		}
+	}
+  	slot_new_button();    
 }
 
 
@@ -637,16 +716,16 @@ void PreferencesDialog::slot_clicked_buttonListView(QListViewItem *lvi, const QP
 {
 	if (!lvi)
 		return;
-  LineEdit_label->setText(lvi->text(1));
-  LineEdit_command->setText(lvi->text(2));
-  LineEdit_help->setText(lvi->text(3));
-  LineEdit_pixfile->setText(lvi->text(4));
+	LineEdit_label->setText(lvi->text(1));
+	LineEdit_command->setText(lvi->text(2));
+	LineEdit_help->setText(lvi->text(3));
+	LineEdit_pixfile->setText(lvi->text(4));
   
 
-  QPixmap p;
-  p.load(LineEdit_pixfile->text());
+	QPixmap p;
+	p.load(LineEdit_pixfile->text());
 
-  pixmapLabel->setPixmap(p);
+	pixmapLabel->setPixmap(p);
 }
 
 
