@@ -302,7 +302,7 @@ bool qGo::soundsFound()
 
 void qGo::playClick()
 {
-	if (setting->readBoolEntry("SOUND_STONE") && clickSound)
+	if (clickSound) //setting->readBoolEntry("SOUND_STONE") && clickSound)
 	{                                                                      //added eb 7
 #ifdef Q_OS_LINUX
 		if (!clickSound->isAvailable())
