@@ -28,6 +28,10 @@
 #include <qtoolbar.h>
 #include <qptrlist.h>
 
+#ifdef Q_OS_MACX
+#include <CoreFoundation/CFString.h>
+#include <CoreFoundation/CFBundle.h>
+#endif //Q_OS_MACX
 
 /*
  *	Playing or Observing
@@ -474,10 +478,12 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 				else if (g->Sz.contains("Black resigns"))
 					qgobrd->send_kibitz(tr("Black resigns"));
 				else */
-					qgobrd->send_kibitz(g->Sz);
+				qgobrd->send_kibitz(g->Sz);
 
 				// set correct result entry
 				QString rs = QString();
+				QString extended_rs = g->Sz;
+
 				if (g->Sz.contains("White forfeits"))
 					rs = "B+T";
 				else if (g->Sz.contains("Black forfeits"))
@@ -518,11 +524,20 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					}
 					
 					if (re1 < 0.2)
+					{
 						rs = "Jigo";
+						extended_rs = "        Jigo         ";
+					}
 					else if (wfirst)
+					{
 						rs = "B+" + QString::number(re1);
+						extended_rs = "Black won by " + QString::number(re1) + " points";
+					}
 					else
+					{
 						rs = "W+" + QString::number(re1);
+						extended_rs = "White won by " + QString::number(re1) + " points";
+					}
 				}
 				else if (g->Sz.contains("White resigns"))
 					rs = "B+R";
@@ -578,6 +593,7 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					bool doSave = ((setting->readBoolEntry("AUTOSAVE")) && (owngame == modeObserve)) ||
 							((setting->readBoolEntry("AUTOSAVE_PLAYED")) && (owngame == modeMatch)); 
 					wrapupMatchGame(qgobrd, doSave);
+					QMessageBox::information(qgobrd->get_win() , tr("Game n ") + QString::number(-qgobrd->get_id()), extended_rs);
 					//else
 					//	qgo->playGameEndSound();
 
@@ -724,8 +740,21 @@ void qGoIF::slot_computer_game(QNewGameDlg * dlg)
 	*/
 	
 	qGoBoard *qb = qgobrd;
-	
-	if (!qgobrd->get_win()->startComputerPlay(dlg,dlg->fileName, qgobrd->get_win()->getFileExtension(dlg->fileName),setting->readEntry("COMPUTER_PATH")))
+
+	QString computerPath = setting->readEntry("COMPUTER_PATH");
+#if defined(Q_OS_MACX)
+	// Default to built-in gnugo on Mac OS X
+	if(computerPath.isNull() || computerPath.isEmpty())
+	{
+	// Default the computer opponent path to built-in gnugo, if available
+	CFURLRef bundleRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
+	CFStringRef bundlePath = CFURLCopyFileSystemPath(bundleRef, kCFURLPOSIXPathStyle);
+	computerPath = (QString)CFStringGetCStringPtr(bundlePath, CFStringGetSystemEncoding())		
+		+ "/Contents/MacOS/gnugo";
+	}
+#endif
+
+	if (!qgobrd->get_win()->startComputerPlay(dlg,dlg->fileName, qgobrd->get_win()->getFileExtension(dlg->fileName), computerPath))
 	{
 		// computer program failed -> end game
 		slot_closeevent();
@@ -1055,8 +1084,9 @@ void qGoIF::slot_requestDialog(const QString &yes, const QString &no, const QStr
 	else
 	{
 		QMessageBox mb(tr("Request of Opponent"),
-			QString(tr("%1 wants to %2\nYES = %3\nCANCEL = %4")).arg(opp).arg(yes).arg(yes).arg(no),
-			QMessageBox::NoIcon,
+			//QString(tr("%1 wants to %2\nYES = %3\nCANCEL = %4")).arg(opp).arg(yes).arg(yes).arg(no),
+			QString(tr("%1 wants to %2\n\nDo you accept ? \n")).arg(opp).arg(yes),
+			QMessageBox::Question,
 			QMessageBox::Yes | QMessageBox::Default,
 			QMessageBox::No | QMessageBox::Escape,
 			QMessageBox::NoButton);
@@ -1300,6 +1330,8 @@ void qGoIF::slot_undo(const QString &player, const QString &move)
 	qb->send_kibitz(tr("GAME MODE: place stones..."));
 }
 
+
+
 // set independent local board
 void qGoIF::set_localboard(QString file)
 {
@@ -1902,7 +1934,8 @@ void qGoBoard::set_move(StoneColor sc, QString pt, QString mv_nr)
 	else if (pt.contains("Pass",false))
 	{
 		win->getBoard()->doSinglePass();
-		qgo->playPassSound();
+		if (win->getBoard()->getBoardHandler()->local_stone_sound)
+			qgo->playPassSound();
 	}
 	else
 	{
@@ -1930,27 +1963,8 @@ void qGoBoard::set_move(StoneColor sc, QString pt, QString mv_nr)
 
 		// avoid sound problem during execution of "moves" cmd
 		if (stated_mv_count > mv_counter)
-		{
 			sound = false;
-/*
-			win->getBoard()->getBoardHandler()->createMoveSGF();
-			win->getBoard()->getBoardHandler()->setModeSGF(modeNormal);
-			win->getBoard()->getBoardHandler()->addStone(sc, i, j, sound);
-			//win->getBoard()->getBoardHandler()->getTree()->getCurrent()->setX(i);
-			//win->getBoard()->getBoardHandler()->getTree()->getCurrent()->setY(j);
-			//win->getBoard()->getBoardHandler()->getTree()->getCurrent()->setColor(sc);
-			//win->getBoard()->getBoardHandler()->updateMove(win->getBoard()->getBoardHandler()->getTree()->getCurrent());
 
-			if (stated_mv_count <= mv_counter + 1)
-			{
-				//win->getBoard()->getBoardHandler()->prepareBoard();
-				win->slotNavLast();
-			}
-
-			//setMode();
-			//win->getBoard()->updateCanvas();
-//*/
-		}
 		else if (gameMode == modeComputer)
 			sound = true;
 
@@ -2397,7 +2411,10 @@ void qGoBoard::slot_doUndo()
     		slot_UndoComputer(myColorIsBlack ? stoneBlack : stoneWhite);
     
   	else if (id > 0)
-		emit signal_sendcommand("undo", false); 
+		if (gsName ==IGS)
+			emit signal_sendcommand("undoplease", false);
+		else
+			emit signal_sendcommand("undo", false); 
 }
 
 void qGoBoard::slot_doAdjourn()
