@@ -15,9 +15,14 @@
 #include <qstringlist.h>
 #include <qstring.h>
 
-#ifdef USE_XPM
+//#ifdef USE_XPM
 #include ICON_APPICON
-#endif
+//#endif
+
+#ifdef Q_OS_MACX
+#include <CoreFoundation/CFString.h>
+#include <CoreFoundation/CFBundle.h>
+#endif //Q_OS_MACX
 
 #ifdef Q_WS_WIN
 #include <windows.h>
@@ -86,6 +91,7 @@ Setting::Setting() : Misc<QString>()
 	writeBoolEntry("STATUSBAR", true);
 	writeBoolEntry("MENUBAR", true);
 	writeEntry("SKIN", "");
+	writeEntry("SKIN_TABLE", "");
 	writeBoolEntry("TOOLTIPS", true);
 	writeBoolEntry("STONES_SHADOW", true);
 	writeBoolEntry("STONES_SHELLS", true);
@@ -108,8 +114,12 @@ Setting::Setting() : Misc<QString>()
 	writeIntEntry("DEFAULT_TIME", 10);
 	writeIntEntry("DEFAULT_BY", 10);
 	writeIntEntry("BY_TIMER", 10);
-  	writeIntEntry("COMPUTER_SIZE", 19);
-	
+	writeIntEntry("COMPUTER_SIZE", 19);
+	writeEntry("LAST_DIR", QDir::homeDirPath());
+#ifdef Q_OS_MACX
+	writeBoolEntry("REM_DIR", true);
+#endif
+
 	// Default ASCII import charset
 	charset = new ASCII_Import();
 	charset->blackStone = '#';
@@ -129,6 +139,7 @@ Setting::Setting() : Misc<QString>()
 	fontClocks = QFont();
   	fontConsole= QFont("Fixed");
 	colorBackground = QColor("white");
+	colorAltBackground = QColor(242,242,242,QColor::Rgb);	
 
 	// init
 	qgo = 0;
@@ -139,11 +150,11 @@ Setting::Setting() : Misc<QString>()
 	applicationPath = getApplicationPath();
 #endif
 
-#ifdef USE_XPM
+//#ifdef USE_XPM
 	image0 = QPixmap((const char **)Bowl_xpm);
-#else
-	image0 = QPixmap(ICON_APPICON);
-#endif
+//#else
+//	image0 = QPixmap(ICON_APPICON);
+//#endif
 }
 
 Setting::~Setting()
@@ -227,10 +238,12 @@ void Setting::loadSettings()
 	updateFont(fontLists, "FONT_LIST");
 	updateFont(fontClocks, "FONT_CLOCK");
 	updateFont(fontConsole, "FONT_CONSOLE");
-	s = readEntry("COLOR_BK");
+ 	s = readEntry("COLOR_BK");
 	if (s)
 		colorBackground = QColor(s);
-
+	s = readEntry("COLOR_ALT_BK");
+	if (s)
+		colorAltBackground = QColor(s);
 	s=readEntry("CHARSET");
 	charset->blackStone = s.constref(0);
 	charset->emptyPoint = s.constref(1);
@@ -306,29 +319,20 @@ void Setting::saveSettings()
 	writeEntry("FONT_CLOCK", fontToString(fontClocks));
 	writeEntry("FONT_CONSOLE", fontToString(fontConsole));
 
-    QString cs = "";
+	QString cs = "";
 
-    cs += QChar(charset->blackStone);
-    cs += QChar(charset->emptyPoint);
-    cs += QChar(charset->hBorder);
-    cs += QChar(charset->starPoint);
-    cs += QChar(charset->vBorder);
-    cs += QChar(charset->whiteStone);
+	cs += QChar(charset->blackStone);
+	cs += QChar(charset->emptyPoint);
+	cs += QChar(charset->hBorder);
+	cs += QChar(charset->starPoint);
+	cs += QChar(charset->vBorder);
+	cs += QChar(charset->whiteStone);
     
-    writeEntry("CHARSET", cs);
-/*	}
-	else
-	{
-		// add fonts and colors
-		writeEntry("FONT_MAIN", "");
-		writeEntry("FONT_MARK", "");
-		writeEntry("FONT_COMMENT", "");
-		writeEntry("FONT_LIST", "");
-		writeEntry("FONT_CLOCK", "");
-    writeEntry("FONT_CONSOLE", "");
-	}
- */ 
+	writeEntry("CHARSET", cs);
+
 	writeEntry("COLOR_BK", colorBackground.name());
+	writeEntry("COLOR_ALT_BK", colorAltBackground.name());
+
 	writeIntEntry("VERSION", SETTING_VERSION);
 
 	list.sort();
@@ -454,6 +458,12 @@ QString Setting::getTranslationsDirectory()
 		<< "D:/Programme/qGo/translations"
 		<< "E:/Programme/qGo/translations"
 		<< "./translations";
+#elif defined(Q_OS_MACX)
+	//get the bundle path and find our resources
+	CFURLRef bundleRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
+	CFStringRef bundlePath = CFURLCopyFileSystemPath(bundleRef, kCFURLPOSIXPathStyle);
+	list << (QString)CFStringGetCStringPtr(bundlePath, CFStringGetSystemEncoding())		
+		+ "/Contents/Resources";
 #else
 	list	<< DATADIR "/" PACKAGE "/translations"
 		<< program_dir + "/translations"
