@@ -96,7 +96,7 @@ public:
 	bool addImportAsBrother;
 	bool fastLoad;
 	QFont fontStandard, fontMarks, fontComments, fontLists, fontClocks, fontConsole;
-	QColor colorBackground;
+	QColor colorBackground, colorAltBackground;
 	QString language;
 	QString program_dir;
 
